import React, { Fragment } from 'react'
import { isEmpty, get } from 'lodash'

import {
  Text,
  Item,
  ContextualBox,
  ManuscriptFileList,
} from 'pubsweet-component-faraday-ui'

const ManuscriptMetadata = ({
  getSignedUrl,
  currentUser: { token },
  fragment: { files = {}, conflicts = {}, metadata: { abstract = '' } },
}) => (
  <Fragment>
    {!!abstract && (
      <Item mb={1}>
        <ContextualBox label="Abstract" startExpanded transparent>
          <Text mb={1} mt={1}>
            {abstract}
          </Text>
        </ContextualBox>
      </Item>
    )}
    {conflicts.hasConflicts === 'yes' && (
      <Item mb={1}>
        <ContextualBox label="Conflict of Interest" transparent>
          <Text mb={1} mt={1}>
            {get(conflicts, 'message', '')}
          </Text>
        </ContextualBox>
      </Item>
    )}
    {!isEmpty(files) && (
      <Item mb={1}>
        <ContextualBox
          label={`Files (${files.coverLetter.length +
            files.manuscripts.length +
            files.supplementary.length})`}
          transparent
        >
          <ManuscriptFileList
            files={files}
            getSignedUrl={getSignedUrl}
            token={token}
          />
        </ContextualBox>
      </Item>
    )}
  </Fragment>
)

export default ManuscriptMetadata
