import { get } from 'lodash'
import { create, update } from 'pubsweet-client/src/helpers/api'

const RECOMMENDATION_REQUEST = 'recommendation/REQUEST'
const RECOMMENDATION_DONE = 'recommendation/DONE'

const recommendationRequest = () => ({
  type: RECOMMENDATION_REQUEST,
})

const recommendationDone = () => ({
  type: RECOMMENDATION_DONE,
})

// #region Selectors
export const selectRecommendations = (state, fragmentId) =>
  get(state, `fragments.${fragmentId}.recommendations`, [])
export const selectEditorialRecommendations = (state, fragmentId) =>
  selectRecommendations(state, fragmentId).filter(
    r => r.recommendationType === 'editorRecommendation' && r.comments,
  )
export const selectReviewRecommendations = (state, fragmentId) =>
  selectRecommendations(state, fragmentId).filter(
    r => r.recommendationType === 'review',
  )

export const recommendationsFetching = state =>
  get(state, 'recommendations', false)
// #endregion

// #region Actions
// error handling and fetching is handled by the autosave reducer
export const createRecommendation = ({
  fragmentId,
  collectionId,
  recommendation,
}) => dispatch => {
  dispatch(recommendationRequest())
  return create(
    `/collections/${collectionId}/fragments/${fragmentId}/recommendations`,
    recommendation,
  ).then(
    res => {
      dispatch(recommendationDone())
      return res
    },
    err => {
      dispatch(recommendationDone())
      throw err
    },
  )
}

export const updateRecommendation = (
  collId,
  fragId,
  recommendation,
) => dispatch => {
  dispatch(recommendationRequest())
  return update(
    `/collections/${collId}/fragments/${fragId}/recommendations/${
      recommendation.id
    }`,
    recommendation,
  ).then(
    res => {
      dispatch(recommendationDone())
      return res
    },
    err => {
      dispatch(recommendationDone())
      throw err
    },
  )
}
// #endregion

export default (state = false, action) => action.type === RECOMMENDATION_REQUEST
